# Installation

The simplest way to install PySHRED is from PyPI.

## Installing from PyPI
PySHRED can be installed via pip from PyPI.

`pip install pyshred`

## Installing from source
PySHRED can be installed via source code on GitHub.

```
git clone https://github.com/PyShred-Dev/PySHRED.git
cd pyshred
pip install .
```